pub struct PendingProposal {
pub block: ProposedBlock,
pub blobs: Vec<Blob>,
pub round: Option<Round>,
}Expand description
A pending proposed block, together with its published blobs.
Fields
block: ProposedBlockThe proposed block.
blobs: Vec<Blob>The blobs published by the proposed block.
round: Option<Round>The round in which this proposal was first submitted, if any.