pub enum LocalNodeError {
ArithmeticError(ArithmeticError),
ViewError(ViewError),
WorkerError(WorkerError),
InactiveChain(ChainId),
InvalidChainInfoResponse,
BlobsNotFound(Vec<BlobId>),
EventsNotFound(Vec<EventId>),
}Expand description
Error type for the operations on a local node.
Variants
ArithmeticError(ArithmeticError)
ViewError(ViewError)
WorkerError(WorkerError)
InactiveChain(ChainId)
InvalidChainInfoResponse
BlobsNotFound(Vec<BlobId>)
EventsNotFound(Vec<EventId>)
Implementations
Sourceimpl LocalNodeError
impl LocalNodeError
Sourcepub fn error_type(&self) -> String
pub fn error_type(&self) -> String
Returns the qualified error variant name for the error_type metric label,
delegating to WorkerError::error_type for wrapped worker errors.