pub struct Memory(/* private fields */);Expand description
A basic implementation of Wallet that doesn’t persist anything and merely tracks the
chains in memory.
This can be used as-is as an ephemeral wallet for testing or ephemeral clients, or as a building block for more complex wallets that layer persistence on top of it.
Implementations
Sourceimpl Memory
impl Memory
pub fn get(&self, id: ChainId) -> Option<Chain>
pub fn insert(&self, id: ChainId, chain: Chain) -> Option<Chain>
pub fn try_insert(&self, id: ChainId, chain: Chain) -> Option<Chain>
pub fn remove(&self, id: ChainId) -> Option<Chain>
pub fn items(&self) -> Vec<(ChainId, Chain)>
pub fn chain_ids(&self) -> Vec<ChainId>
pub fn owned_chain_ids(&self) -> Vec<ChainId>
pub fn mutate<R>( &self, chain_id: ChainId, mutate: impl FnMut(&mut Chain) -> R, ) -> Option<R>