Module node

Module node 

Traits for communicating with validator nodes.

Structs

InvalidTimestampError
Parsed data from an InvalidTimestamp error.

Enums

CrossChainMessageDelivery
Whether to wait for the delivery of outgoing cross-chain messages.
NodeError
Error type for node queries.

Traits

ValidatorNode
How to communicate with a validator node.
ValidatorNodeProvider
Turn an address into a validator node.

Type Aliases

BlobStream
A pinned Stream of blob contents returned by batch downloads.
NotificationStream
A pinned Stream of Notifications.