pub struct ChannelNotifier<N> { /* private fields */ }Expand description
A Notifier holds references to clients waiting to receive notifications
from the validator.
Clients will be evicted if their connections are terminated.
Implementations
Sourceimpl<N> ChannelNotifier<N>
impl<N> ChannelNotifier<N>
Sourcepub fn add_sender(&self, chain_ids: Vec<ChainId>, sender: &UnboundedSender<N>)
pub fn add_sender(&self, chain_ids: Vec<ChainId>, sender: &UnboundedSender<N>)
Registers a sender for notifications on the given chain IDs.
Sourcepub fn subscribe(&self, chain_ids: Vec<ChainId>) -> UnboundedReceiver<N>
pub fn subscribe(&self, chain_ids: Vec<ChainId>) -> UnboundedReceiver<N>
Creates a subscription given a collection of chain IDs and a sender to the client.
Sourcepub fn subscribe_with_ack(
&self,
chain_ids: Vec<ChainId>,
ack: N,
) -> UnboundedReceiver<N>
pub fn subscribe_with_ack( &self, chain_ids: Vec<ChainId>, ack: N, ) -> UnboundedReceiver<N>
Creates a subscription given a collection of chain IDs and a sender to the client. Immediately posts a first notification as an ACK.
Sourceimpl<N> ChannelNotifier<N>where
N: Clone,
impl<N> ChannelNotifier<N>where
N: Clone,
Sourcepub fn notify_chain(&self, chain_id: &ChainId, notification: &N)
pub fn notify_chain(&self, chain_id: &ChainId, notification: &N)
Notifies all the clients waiting for a notification from a given chain.