pub enum WorkerError {
Show 27 variants
CryptoError(CryptoError),
ArithmeticError(ArithmeticError),
ViewError(ViewError),
ReadCertificatesError(Vec<CryptoHash>),
ChainError(Box<ChainError>),
BcsError(Error),
InvalidOwner,
InvalidSigner(AccountOwner),
UnexpectedBlockHeight {
expected_block_height: BlockHeight,
found_block_height: BlockHeight,
},
InvalidEpoch {
chain_id: ChainId,
chain_epoch: Epoch,
epoch: Epoch,
},
EventsNotFound(Vec<EventId>),
InvalidCrossChainRequest,
InvalidBlockChaining,
InvalidTimestamp {
block_timestamp: Timestamp,
local_time: Timestamp,
block_time_grace_period: Duration,
},
MissingCertificateValue,
LocalBlockNotFound {
height: BlockHeight,
chain_id: ChainId,
},
InvalidLiteCertificate,
FastBlockUsingOracles,
BlobsNotFound(Vec<BlobId>),
ConfirmedBlockHashNotFound {
height: BlockHeight,
chain_id: ChainId,
},
InvalidBlockProposal(String),
UnexpectedBlob,
TooManyPublishedBlobs(u64),
MissingNetworkDescription,
Thread(Error),
NoFallbackMode,
PoisonedWorker,
}Expand description
Error type for worker operations.
Variants
CryptoError(CryptoError)
ArithmeticError(ArithmeticError)
ViewError(ViewError)
ReadCertificatesError(Vec<CryptoHash>)
ChainError(Box<ChainError>)
BcsError(Error)
InvalidOwner
InvalidSigner(AccountOwner)
UnexpectedBlockHeight
InvalidEpoch
EventsNotFound(Vec<EventId>)
InvalidCrossChainRequest
InvalidBlockChaining
InvalidTimestamp
MissingCertificateValue
LocalBlockNotFound
InvalidLiteCertificate
FastBlockUsingOracles
BlobsNotFound(Vec<BlobId>)
ConfirmedBlockHashNotFound
InvalidBlockProposal(String)
UnexpectedBlob
TooManyPublishedBlobs(u64)
MissingNetworkDescription
Thread(Error)
NoFallbackMode
PoisonedWorker
Implementations
Sourceimpl WorkerError
impl WorkerError
Sourcepub fn is_local(&self) -> bool
pub fn is_local(&self) -> bool
Returns whether this error is caused by an issue in the local node.
Returns false whenever the error could be caused by a bad message from a peer.
Sourcepub fn error_type(&self) -> String
pub fn error_type(&self) -> String
Returns the qualified error variant name for the error_type metric label,
e.g. "WorkerError::UnexpectedBlockHeight".
For ChainError variants, delegates to ChainError::error_type() to
surface the underlying error name rather than just "ChainError".