pub struct ChainClientOptions {Show 13 fields
pub max_pending_message_bundles: usize,
pub max_block_limit_errors: u32,
pub max_new_events_per_block: usize,
pub staging_bundles_time_budget: Option<Duration>,
pub message_policy: MessagePolicy,
pub cross_chain_message_delivery: CrossChainMessageDelivery,
pub quorum_grace_period: f64,
pub blob_download_timeout: Duration,
pub certificate_batch_download_timeout: Duration,
pub certificate_download_batch_size: u64,
pub sender_certificate_download_batch_size: usize,
pub max_joined_tasks: usize,
pub allow_fast_blocks: bool,
}Fields
max_pending_message_bundles: usizeMaximum number of pending message bundles processed at a time in a block.
max_block_limit_errors: u32Maximum number of message bundles to discard from a block proposal due to block limit errors before discarding all remaining bundles.
Discarded bundles can be retried in the next block.
max_new_events_per_block: usizeMaximum number of new stream events processed at a time in a block.
staging_bundles_time_budget: Option<Duration>Time budget for staging message bundles. When set, limits bundle execution by
wall-clock time, in addition to the count limit from max_pending_message_bundles.
message_policy: MessagePolicyThe policy for automatically handling incoming messages.
cross_chain_message_delivery: CrossChainMessageDeliveryWhether to block on cross-chain message delivery.
quorum_grace_period: f64An additional delay, after reaching a quorum, to wait for additional validator signatures, as a fraction of time taken to reach quorum.
blob_download_timeout: DurationThe delay when downloading a blob, after which we try a second validator.
certificate_batch_download_timeout: DurationThe delay when downloading a batch of certificates, after which we try a second validator.
certificate_download_batch_size: u64Maximum number of certificates that we download at a time from one validator when synchronizing one of our chains.
sender_certificate_download_batch_size: usizeMaximum number of sender certificates we try to download and receive in one go when syncing sender chains.
max_joined_tasks: usizeMaximum number of tasks that can be joined concurrently using buffer_unordered.
allow_fast_blocks: boolWhether to allow creating blocks in the fast round. Fast blocks have lower latency but must be used carefully so that there are never any conflicting fast block proposals.
Implementations
Sourceimpl ChainClientOptions
impl ChainClientOptions
Sourcepub fn bundle_execution_policy(&self) -> BundleExecutionPolicy
pub fn bundle_execution_policy(&self) -> BundleExecutionPolicy
Builds the BundleExecutionPolicy based on the client options.