pub struct Client<Env: Environment> {
pub local_node: LocalNodeClient<Env::Storage>,
/* private fields */
}Expand description
A builder that creates ChainClients which share the cache and notifiers.
Fields
local_node: LocalNodeClient<Env::Storage>Local node to manage the execution state and the local storage of the chains that we are tracking.
Implementations
Sourceimpl<Env: Environment> Client<Env>
impl<Env: Environment> Client<Env>
Sourcepub fn new(
environment: Env,
admin_chain_id: ChainId,
long_lived_services: bool,
chain_modes: impl IntoIterator<Item = (ChainId, ListeningMode)>,
name: impl Into<String>,
chain_worker_ttl: Option<Duration>,
sender_chain_worker_ttl: Option<Duration>,
cross_chain_batch_size_limit: usize,
options: Options,
requests_scheduler_config: &RequestsSchedulerConfig,
block_cache_size: usize,
execution_state_cache_size: usize,
) -> Self
pub fn new( environment: Env, admin_chain_id: ChainId, long_lived_services: bool, chain_modes: impl IntoIterator<Item = (ChainId, ListeningMode)>, name: impl Into<String>, chain_worker_ttl: Option<Duration>, sender_chain_worker_ttl: Option<Duration>, cross_chain_batch_size_limit: usize, options: Options, requests_scheduler_config: &RequestsSchedulerConfig, block_cache_size: usize, execution_state_cache_size: usize, ) -> Self
Creates a new Client with a new cache and notifiers.
Sourcepub fn admin_chain_id(&self) -> ChainId
pub fn admin_chain_id(&self) -> ChainId
Returns the chain ID of the admin chain.
Sourcepub fn subscribe(
&self,
chain_ids: Vec<ChainId>,
) -> UnboundedReceiver<Notification>
pub fn subscribe( &self, chain_ids: Vec<ChainId>, ) -> UnboundedReceiver<Notification>
Subscribes to notifications for the given chain IDs.
Sourcepub fn subscribe_extra(
&self,
chain_ids: Vec<ChainId>,
sender: &UnboundedSender<Notification>,
)
pub fn subscribe_extra( &self, chain_ids: Vec<ChainId>, sender: &UnboundedSender<Notification>, )
Adds additional chain IDs to an existing subscription.
Sourcepub fn storage_client(&self) -> &Env::Storage
pub fn storage_client(&self) -> &Env::Storage
Returns the storage client used by this client’s local node.
Sourcepub fn validator_node_provider(&self) -> &Env::Network
pub fn validator_node_provider(&self) -> &Env::Network
Returns the provider used to connect to validator nodes.
Sourcepub async fn retry_pending_cross_chain_requests(
&self,
sender_chain: ChainId,
) -> Result<(), LocalNodeError>
pub async fn retry_pending_cross_chain_requests( &self, sender_chain: ChainId, ) -> Result<(), LocalNodeError>
Handles any pending local cross-chain requests, notifying subscribers.
Sourcepub async fn has_key_for(&self, owner: &AccountOwner) -> Result<bool, Error>
pub async fn has_key_for(&self, owner: &AccountOwner) -> Result<bool, Error>
Returns whether the signer has a key for the given owner.
Sourcepub fn extend_chain_mode(
&self,
chain_id: ChainId,
mode: ListeningMode,
) -> ListeningMode
pub fn extend_chain_mode( &self, chain_id: ChainId, mode: ListeningMode, ) -> ListeningMode
Extends the listening mode for a chain, combining with the existing mode if present. Returns the resulting mode.
Sourcepub fn chain_mode(&self, chain_id: ChainId) -> Option<ListeningMode>
pub fn chain_mode(&self, chain_id: ChainId) -> Option<ListeningMode>
Returns the listening mode for a chain, if it is tracked.
Sourcepub fn is_tracked(&self, chain_id: ChainId) -> bool
pub fn is_tracked(&self, chain_id: ChainId) -> bool
Returns whether a chain is fully tracked by the local node.
Sourcepub fn create_chain_client(
self: &Arc<Self>,
chain_id: ChainId,
block_hash: Option<CryptoHash>,
next_block_height: BlockHeight,
pending_proposal: &Option<PendingProposal>,
preferred_owner: Option<AccountOwner>,
timing_sender: Option<UnboundedSender<(u64, TimingType)>>,
) -> ChainClient<Env>
pub fn create_chain_client( self: &Arc<Self>, chain_id: ChainId, block_hash: Option<CryptoHash>, next_block_height: BlockHeight, pending_proposal: &Option<PendingProposal>, preferred_owner: Option<AccountOwner>, timing_sender: Option<UnboundedSender<(u64, TimingType)>>, ) -> ChainClient<Env>
Creates a new ChainClient.
Sourcepub async fn admin_committee(
&self,
) -> Result<(Epoch, Arc<Committee>), LocalNodeError>
pub async fn admin_committee( &self, ) -> Result<(Epoch, Arc<Committee>), LocalNodeError>
Obtains the committee for the latest epoch on the admin chain.
See admin_committees for the fallback rationale (transitional).
Sourcepub async fn get_chain_description_blob(
&self,
chain_id: ChainId,
) -> Result<Arc<Blob>, Error>
pub async fn get_chain_description_blob( &self, chain_id: ChainId, ) -> Result<Arc<Blob>, Error>
Ensures that the client has the ChainDescription blob corresponding to this
client’s ChainId, and returns the chain description blob.
Sourcepub async fn get_chain_description(
&self,
chain_id: ChainId,
) -> Result<ChainDescription, Error>
pub async fn get_chain_description( &self, chain_id: ChainId, ) -> Result<ChainDescription, Error>
Ensures that the client has the ChainDescription blob corresponding to this
client’s ChainId, and returns the chain description.
Sourcepub async fn get_application_description_blob(
&self,
application_id: ApplicationId,
) -> Result<Arc<Blob>, Error>
pub async fn get_application_description_blob( &self, application_id: ApplicationId, ) -> Result<Arc<Blob>, Error>
Ensures that the client has the ApplicationDescription blob for the given
application ID, fetching it from the current validators if it is not available
locally, and returns the blob. The application need not be registered on this
client’s chain: the description is content-addressed and downloaded by blob ID.
Sourcepub async fn get_application_description(
&self,
application_id: ApplicationId,
) -> Result<ApplicationDescription, Error>
pub async fn get_application_description( &self, application_id: ApplicationId, ) -> Result<ApplicationDescription, Error>
Returns the ApplicationDescription of the given application, fetching its
description blob from the validators if it is not available locally.
Sourcepub async fn synchronize_chain_state_from_committee(
&self,
chain_id: ChainId,
committee: Arc<Committee>,
) -> Result<Box<ChainInfo>, Error>
pub async fn synchronize_chain_state_from_committee( &self, chain_id: ChainId, committee: Arc<Committee>, ) -> Result<Box<ChainInfo>, Error>
Downloads certificates for the given chain from the given committee.
If the chain is not in follow-only mode, also fetches and processes manager values (timeout certificates, proposals, locking blocks) for consensus participation.