pub struct ChainWorkerConfig {Show 17 fields
pub nickname: String,
pub key_pair: Option<Arc<ValidatorSecretKey>>,
pub allow_inactive_chains: bool,
pub allow_messages_from_deprecated_epochs: bool,
pub long_lived_services: bool,
pub block_time_grace_period: Duration,
pub ttl: Option<Duration>,
pub sender_chain_ttl: Option<Duration>,
pub chain_info_max_received_log_entries: usize,
pub block_cache_size: usize,
pub execution_state_cache_size: usize,
pub priority_bundle_origins: HashSet<ChainId>,
pub ignored_bundle_origins: HashSet<ChainId>,
pub cross_chain_message_chunk_limit: usize,
pub allow_revert_confirm: bool,
pub reset_on_corrupted_chain_state: Option<Duration>,
pub recovery_whitelist: Option<HashSet<ChainId>>,
}Expand description
Configuration parameters for the chain worker and its owning
WorkerState.
Fields
nickname: StringA name used for logging.
key_pair: Option<Arc<ValidatorSecretKey>>The signature key pair of the validator. The key may be missing for replicas without voting rights (possibly with a partial view of chains).
allow_inactive_chains: boolWhether inactive chains are allowed in storage.
allow_messages_from_deprecated_epochs: boolWhether new messages from deprecated epochs are allowed.
long_lived_services: boolWhether the user application services should be long-lived.
block_time_grace_period: DurationBlocks with a timestamp this far in the future will still be accepted, but the validator will wait until that timestamp before voting.
ttl: Option<Duration>Idle chain workers free their memory after this duration without requests.
None means no expiry (handle lives forever).
sender_chain_ttl: Option<Duration>TTL for sender chains. None means no expiry.
chain_info_max_received_log_entries: usizeThe size to truncate receive log entries in chain info responses.
block_cache_size: usizeMaximum number of entries in the block cache.
execution_state_cache_size: usizeMaximum number of entries in the execution state cache.
priority_bundle_origins: HashSet<ChainId>Chain IDs whose incoming bundles should be processed first.
ignored_bundle_origins: HashSet<ChainId>Chain IDs whose incoming bundles should be ignored.
cross_chain_message_chunk_limit: usizeMaximum estimated serialized size of bundles in a single UpdateRecipient
cross-chain message. When exceeded, the bundles are split into multiple requests.
Defaults to usize::MAX (no chunking).
allow_revert_confirm: boolWhether to attempt recovery via RevertConfirm when an inbox gap is detected.
reset_on_corrupted_chain_state: Option<Duration>If set, reset the chain state and re-execute all blocks when the chain state is detected to be corrupted — but only if the given duration has elapsed since block 0 was last executed (to prevent reset loops).
recovery_whitelist: Option<HashSet<ChainId>>Optional whitelist restricting which chains are eligible for the
allow_revert_confirm and reset_on_corrupted_chain_state recovery
mechanisms. If None, every chain is eligible (subject to the
respective feature flag). If Some, only chains in the set are.
Implementations
Sourceimpl ChainWorkerConfig
impl ChainWorkerConfig
Sourcepub fn with_key_pair(self, key_pair: Option<ValidatorSecretKey>) -> Self
pub fn with_key_pair(self, key_pair: Option<ValidatorSecretKey>) -> Self
Configures the key_pair in this ChainWorkerConfig.
Sourcepub fn key_pair(&self) -> Option<&ValidatorSecretKey>
pub fn key_pair(&self) -> Option<&ValidatorSecretKey>
Gets a reference to the ValidatorSecretKey, if available.