ProcessableCertificate

Trait ProcessableCertificate 

pub trait ProcessableCertificate:
    CertificateValue
    + Sized
    + 'static
    + Send {
    // Required method
    fn process_certificate<S: Storage + Clone + 'static>(
        worker: &WorkerState<S>,
        certificate: GenericCertificate<Self>,
    ) -> impl Future<Output = Result<(ChainInfoResponse, NetworkActions), WorkerError>> + Send;
}
A certificate value that the worker knows how to process.

Required Methods

fn process_certificate<S: Storage + Clone + 'static>( worker: &WorkerState<S>, certificate: GenericCertificate<Self>, ) -> impl Future<Output = Result<(ChainInfoResponse, NetworkActions), WorkerError>> + Send

Processes a certificate carrying this value on the given worker.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ProcessableCertificate for ConfirmedBlock

Source

impl ProcessableCertificate for Timeout

Source

impl ProcessableCertificate for ValidatedBlock

Implementors