pub trait ProcessableCertificate:
CertificateValue
+ Sized
+ 'static
+ Send {
// Required method
fn process_certificate<S: Storage + Clone + 'static>(
worker: &WorkerState<S>,
certificate: GenericCertificate<Self>,
) -> impl Future<Output = Result<(ChainInfoResponse, NetworkActions), WorkerError>> + Send;
}Expand description
A certificate value that the worker knows how to process.
Required Methods
Sourcefn process_certificate<S: Storage + Clone + 'static>(
worker: &WorkerState<S>,
certificate: GenericCertificate<Self>,
) -> impl Future<Output = Result<(ChainInfoResponse, NetworkActions), WorkerError>> + Send
fn process_certificate<S: Storage + Clone + 'static>( worker: &WorkerState<S>, certificate: GenericCertificate<Self>, ) -> impl Future<Output = Result<(ChainInfoResponse, NetworkActions), WorkerError>> + Send
Processes a certificate carrying this value on the given worker.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".